Cepton Python SDK
=================

## Installation

```sh
pip install -U cepton_sdk
```

To install extra dependencies

```sh
pip install -U cepton_sdk[export,plot]
```

## Documentation

- `docs/html/index.html`
